C
      SUBROUTINE DENSITYDATA(Znucleus, Anucleus, Alevel, Backshift)
C
C     ******************************************************************
C     * Assignment of the level density parameters to nucleus with     *
C     * atomic number 'Znucleus' and  mass number 'Anucleus' .         *
C     *                                                                *
C     * 'Alevel' = the level density parameter a;                      *
C     * 'Backshift' = the backshift parameter.                         *
C     *                                                                *
C     *  Attempts are made  initially to set the parameters from       *
C     *  "denslib.dat" file (extracted from "beijing_bs1.dat",         *
C     *  see RIPL, for backshifted Fermi gas model with rigid-body     *
C     *  value for moment inertia)                                     *
C     *                                                                *
C     *  If parameters are not found in "denslib.dat" then             *
C     *  systematics given by Von Egidy et al Nucl.Phys.A481(1988)189  *
C     *  are used.                                                     *
C     ******************************************************************
C
      IMPLICIT NONE
      DOUBLE PRECISION aa, Alevel, Backshift, backsl, c1, delta,
     &                 halevel, hbacksl, xi, Znucleus, Anucleus
      INTEGER ii, ka, keyload, kz, nna, nnz, kzz,  kaa  
      DIMENSION nnz(500), nna(500), halevel(500), hbacksl(500)
      DATA keyload/0/, kzz/0/, kaa/0/
      kz = Znucleus + 0.001
      ka = Anucleus + 0.001
      IF(kz.EQ.kzz .AND. ka.EQ.kaa) GOTO 99999 
      kzz=kz
      kaa=ka
      IF(keyload.NE.1)THEN
         keyload = 1
         OPEN(83, FILE = 'denslib.dat')
         REWIND 83
         DO ii = 1, 404
            READ(83, 99001, END = 50, ERR = 50)nnz(ii), nna(ii),
     &           halevel(ii), hbacksl(ii)
99001       FORMAT(I2, I4, F7.3, F6.2)
 50      ENDDO
      ENDIF
      DO ii = 1, 404
         IF(kz.EQ.nnz(ii) .AND. kz.EQ.nna(ii))THEN
            Alevel = halevel(ii)
            backsl = hbacksl(ii)
            IF(ABS(Alevel).LT.0.001)GOTO 100
            Backshift = backsl
            GOTO 99999
         ENDIF
      ENDDO
C     ********************************************************
C     * Systematics given by Von Egidy, Behkami, Schmidt,    *
C     * Nucl.Phys. A481(1988)189.                            *
C     ********************************************************
 100  aa = ka
      Alevel = 0.21*aa**0.87
      c1 = -6.6/aa**0.32
      xi = 1.
      IF(ka/2*2.EQ.ka)THEN
         xi = 0.
         IF(kz/2*2.EQ.kz)xi = 2.
      ENDIF
      delta = xi*12./SQRT(aa)
      Backshift = c1 + delta
99999 END

