C
      DOUBLE PRECISION FUNCTION TEMPERATURE(Eexcitf,
     &                                     Alevel, Backshift, Keydens)
C        **********************************************************************
C        * Calculation of the temperature as a function of excitation         *
C        * energy 'Eexcitf';                                                  *
C        *                                                                    *
C        * 'Alevel' = the level density parameter a;                          *
C        * 'Backshift' = the backshift parameter;                             *
C        *                                                                    *
C        * 'Keydens' = key to specify the thermodynamic state equation        *
C        *             for relationship between excitation energy and         *
C        *             the temperature:                                       *
C        *                                                                    *
C        *  Keydens = 1 --> Fermi-gas model;                                  *
C        *  Keydens = 2 --> Backshifted Fermi-gas model(BFGM)                 *
C        *                  by W.Dilg, W.Schantl,H.Vonach,M.Uhl               *
C        *                  NP A217(1973)269, Eq.(3).                         *
C        **********************************************************************
      IMPLICIT NONE
      DOUBLE PRECISION Alevel, Backshift, Eexcitf, h
      INTEGER Keydens
      IF(Keydens.EQ.1)THEN
         TEMPERATURE = 1.E-6
         IF(Eexcitf.LE.1.E-6)RETURN
         TEMPERATURE = SQRT(Eexcitf/Alevel)
      ELSE
         h = 4.0*Alevel*(Eexcitf - Backshift)
         IF(h.GT.0.1E-03)THEN
            TEMPERATURE = (1. + SQRT(1.0 + h))/2.0/Alevel
         ELSE
            TEMPERATURE = 1./Alevel
         ENDIF
      ENDIF
      END
